@@ -2,7 +2,7 @@ package Foo;
 
 use Test::Class::Moose bare => 1;
 
-use Test2::Bundle::Extended '!meta';
+use Test2::V0 '!meta';
 
 our $LOADED = 1;
 
